@@ -130,7 +130,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     async def _create_browser_context(self, name: str, context_kwargs: dict) -> BrowserContext:
         context = await self.browser.new_context(**context_kwargs)
-        context.on("close", self._make_close_browser_context_callback(name))
+        # context.on("close", self._make_close_browser_context_callback(name))
         logger.debug("Browser context started: '%s'", name)
         self.stats.inc_value("playwright/context_count")
         if self.default_navigation_timeout is not None:
@@ -250,7 +250,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
-        response = await page.goto(request.url)
+        response = await page.goto(request.url, wait_until="commit")
 
         logger.info(f"[{request.url}] After goto")
         await self._apply_page_methods(page, request)
